################################################################
DORIS
################################################################

:Author: `Olivier Friard <http://www.di.unito.it/~friard>`_


DORIS is an easy-to-use interactive object detection and tracking software with a graphical user interface.

DORIS is a free and open-source software available for GNU/Linux, Windows and Mac OS.

This project is at an early stage of development. Please report any bugs and suggestions using the GitHub issues tracker.

DORIS web page: `http://www.boris.unito.it/pages/doris <http://www.boris.unito.it/pages/doris>`_

This project was inspired by the **Tracktor project**: https://github.com/vivekhsridhar/tracktor https://besjournals.onlinelibrary.wiley.com/doi/abs/10.1111/2041-210X.13166

Requirements
========================================================================================

* matplotlib
* numpy
* opencv-python-headless (>=4.0.0)
* pandas
* PyQt5
* scikit-learn
* scipy
* sklearn


User guide
========================================================================================

https://doris.readthedocs.io/en/latest/

A video tutorial is available at https://www.youtube.com/watch?v=toSXiqsWRzY (no audio)


Download binaries (executable versions for Linux, Windows and Mac OS)
========================================================================================

See the `Releases page <https://github.com/olivierfriard/DORIS/releases>`_



